PyNeat
======

.. _tensorflow: https://www.tensorflow.org/

An implementation of Kenneth O. Stanley's NEAT algorithm using tensorflow_ for the back end.

Installation
------------

.. code:: sh

  pip install -U pyneat


Usage Example
-------------

.. literalinclude:: pyneat/examples/pole.py
